/**********************************************************************************************/
/* Replication files for                                                                      */
/* Jessen, Robin, Rostam-Afschar, Davud, and Schmitz, Sebastian                               */
/* "How Important is Precautionary Labor Supply?" (2016)                                      */
/* data_processing.do                                                                         */
/**********************************************************************************************/

if ${REGIONAL}==1{ /* load spatial planning regions */
	use "${GEOCODES_PATH}ror_l", clear
	replace year=year-1
	save "${GEOCODES_PATH}ror_l_year", replace
}

*---------------------------------[Pull SOEP data]-----------------------------------*/ 
clear
# del;
use pid hid syear phrf gebjahr sex sampreg psample netto
using "${SOEP_LONG_PATH}ppfadl.dta" if syear>${FIRSTYEAR} & syear<=${LASTYEAR}+1;
drop if pid==.; 

merge 1:1 pid syear using "${SOEP_LONG_PATH}pl.dta", 
keepusing(plb0022 plb0195 plb0241 plh0033  plc0343  plc0411 
plc0357  plc0416 plc0329 plc0335 plc0366 plc0371 plc0422 plc0348 plc0347 
 plc0361 plc0362 plc0333 plc0334 plc0334);   	
drop if _merge==2;
drop _merge;

merge 1:1 pid syear using "${SOEP_LONG_PATH}pgen.dta", keepusing(pgisced cid pglabgro pglabnet pgerwzt pgexpft pgexppt pgtatzt pgnace pgvebzt pguebstd  pgstib pgbilzt
syear pid pgexpue);
drop if _merge==2;
drop _merge;

merge 1:1 pid syear  
using "${SOEP_LONG_PATH}pbrutto.dta", keepusing(stell);
drop if _merge==2;
drop _merge;

merge m:1 hid syear  
using "${SOEP_LONG_PATH}hgen.dta", keepusing(hgahinc);
drop if _merge==2;
drop _merge;

merge m:1 hid syear  
using "${SOEP_LONG_PATH}hbrutto.dta", keepusing(bula);
drop if _merge==2;
drop _merge;

gen hhnrakt=hid;
gen svyyear=syear;

merge m:1 hhnrakt svyyear  
using "${SOEP_WIDE_PATH}hwealth.dta", keepusing(w010ha w010hb w010hc w010hd w010he w020h0 w011ha
 w011hb w011hc w011hd w011he w022h0 f100h0 f200h0 f010ha f010hb f010hc f010hd f010he f020h0);
drop if _merge==2;
drop _merge;

merge  1:1 pid syear   	
using "${SOEP_LONG_PATH}pequiv.dta" 
, keepusing(ijob1 ijob2 iself i11101 i11102 e11101 e11105);
drop if _merge==2;
drop _merge;

merge  m:1 hid syear   	
using "${SOEP_LONG_PATH}hl.dta" 
, keepusing(hlc0043 hlc0048 hlc0052 hlc0120);
drop if _merge==2;
drop _merge;

#del cr
/* data are retrospective: */	
gen year=syear-1
qui tab year, gen(yeard)
gen hhnr=cid

if ${REGIONAL}==1{
	cap drop _merge
	merge m:1 hhnr hhnrakt year using "${GEOCODES_PATH}ror_l_year", keepusing(ror8595 ror96 nuts2)
	drop if _merge==2
	drop _merge
	gen ror=.
	replace ror= ror8595 if year<1995
	replace ror= ror96 if year>1994
}
else{
}

sort pid year
drop if year==. 
xtset pid year

*---------------------------------[Data-Processing]-----------------------------------*
qui sum year
local highest_year=r(max)
local firstyear=${FIRSTYEAR}

/*gen personal net worth*/
#d;
gen pnetworth = plc0343 - plc0411
    + plc0357 - plc0416
    + plc0329
    + plc0335
    + plc0366
    + plc0371
    - plc0422;
label variable pnetworth "Personal net worth";
#d cr

/* Set missings and top-coding to missings */
replace plb0241 = . if plb0241<0 | plb0241>80 /* Desired weekly hours larger than 80 */
replace pglabgro=. if pglabgro<0 | pglabgro>=70000  /* Monthly gross labor inc >70k */
replace pglabnet=. if pglabgro<0 | pglabgro>=70000  /* Monthly gross labor inc >70k */
drop if pglabgro<pglabnet & pglabgro!=. & pglabnet!=.  /* Drop observations with inconsistent gross vs net labor income */
replace e11101=. if e11101<0 | e11101>4160 /* Annual hours larger than 80*52 */  
foreach var in pgtatzt pgvebzt plb0241{
	replace `var'=. if `var'<0 | `var'>80 /* Weekly hours larger than 80 */
}
foreach var in 	pgbilzt pgerwzt pguebstd pgnace pgisced pgstib pglabgro pglabnet pgexpft pgexppt pgexpue { /* Properly define missings */
	replace `var'=. if `var'<0 
}

/* Generate paid overtime and paid working hours*/
gen overtime_paid = 0
replace overtime_paid = pgtatzt-pgvebzt if plb0195==3 & pgtatzt-pgvebzt>0
replace overtime_paid = 0.5*(pgtatzt-pgvebzt) if plb0195==2  & pgtatzt-pgvebzt>0 /* c.f. Euwals 2005, Formula (13) */
label var overtime_paid "Hours of paid Overtime, own construction" 
gen paid_hours = pgvebzt+overtime_paid
replace paid_hours= pgtatzt if paid_hours==.  
label var paid_hours "Paid hours, own construction"

foreach var in pgtatzt e11101 pgvebzt pguebstd plb0241 paid_hours{
	replace `var'=. if `var'<0
}
	replace paid_hours=. if paid_hours<0 | paid_hours>80

/* Generate SOEP overtime */
gen dovertime=0
replace dovertime=1 if pguebstd>0 & pguebstd!=. 
label var dovertime "Overtime, SOEP definition" 

gen dovertime_paid=0
replace dovertime_paid=1 if overtime_paid>0 & overtime_paid!=. 
label var dovertime_paid "Overtime, own definition" 

gen overtime=pguebstd
label var overtime "Hours of overtime work, SOEP definition"

/* Generate second job indicator */
gen second_job=0
replace second_job=1 if ijob2>0 & ijob2!=.
label var second_job "Second job" 

/* Generate Gross wages for different hours concpets */
foreach var in pgtatzt pgvebzt paid_hours{
	gen double whr_`var'=pglabgro/(`var'*4.33) if `var'>0 & pglabgro>0
}
gen double whr_e11101 =pglabgro/(e11101/12) if e11101>0 & pglabgro>0
gen double whr_plb0241=whr_pgtatzt 
gen double uninc=max(0,hgahinc-pglabnet)

/* monthly savings
Bleibt Ihnen in der Regel monatlich ein gewisser Betrag übrig, den Sie sparen
oder zurücklegen können, etwa für größere Anschaffungen, für Notlagen oder zur
Vermögensbildung?*/

gen double savings = hlc0120
replace savings=0 if hlc0120==-2
replace savings=. if savings<0

/*unearned income */
gen pglabgro_mis=pglabgro 
replace pglabgro_mis=0 if pglabgro_mis==.
replace uninc=max(0,(i11101)-pglabgro_mis*12)
drop pglabgro_mis

/*income of other hh members*/
gen other_inc_net=i11102/12-pglabnet
replace other_inc_net=0 if other_inc_net<0 & other_inc_net>-250
replace other_inc_net=. if other_inc_net<=-250
lab var other_inc_net "other hh members' net income per month"

gen lother_inc_net=ln(i11102/12-pglabnet + 0.01)
lab var lother_inc_net "log of other hh members' net income per month"

if ${NETWAGES}==1 {
/* Merge net wages simulated with STSM microsimulation model */
	save "${DATA_PATH}hours_estimation_temp.dta", replace
	forvalues year=`firstyear'/`highest_year'{
		if `year'==`firstyear'{
			use "${STSM_PATH}disposable_income`year'_obs_all_2000_Year_sebschmitz", clear
		}
		else{
			append using "${STSM_PATH}disposable_income`year'_obs_all_2000_Year_sebschmitz"
		}
	}
	save "${DATA_PATH}net_wages.dta", replace
	
	use "${DATA_PATH}hours_estimation_temp.dta",clear
	merge 1:1 pid year using "${DATA_PATH}net_wages.dta", keepusing(virtual_income net_income_hh net_income_hh_2000 algII shtrans)
	drop if _merge==2
	erase "${DATA_PATH}hours_estimation_temp.dta"
	drop _merge
	
	/* Exclude transfer recipients */
	bys pid: egen max_algII=max(algII)
	replace net_income_hh_2000=. if max_algII>0 & max_algII<.
	bys pid: egen max_shtrans=max(shtrans)
	replace net_income_hh_2000=. if max_shtrans>0 & max_shtrans<.
	drop max_shtrans max_algII
	
	/* gen net wage */
	foreach var in pgtatzt pgvebzt paid_hours e11101 {
	gen double net_wage_`var'=(net_income_hh_2000-net_income_hh)/(2000)*whr_`var' 
	replace net_wage_`var'=. if net_wage_`var'<=0 | (net_income_hh_2000-net_income_hh)>2000
	replace net_wage_`var'=. if net_wage_`var'<1 
	}
	gen double net_wage_plb0241=net_wage_pgtatzt
	
	/* gen virtual income */
	foreach var in pgtatzt pgvebzt paid_hours{ /* weekly basis */
	gen double virtual_income_`var'=net_income_hh/52-net_wage_`var'*`var' 
	replace virtual_income_`var'=. if virtual_income_`var'<0 | (net_income_hh_2000-net_income_hh)>2000
	}
	gen double virtual_income_e11101=net_income_hh-net_wage_e11101*e11101 /* annual basis */
	replace virtual_income_e11101=. if virtual_income_e11101<0 | (net_income_hh_2000-net_income_hh)>2000
	gen double virtual_income_plb0241=virtual_income_pgtatzt
}
	
/* Occupational categories */ 
gen bluecollar = 0
replace bluecollar = 1 if pgstib==220 | pgstib==230 | pgstib==240 | pgstib==250
gen whitecollar = 0
replace whitecollar = 1 if (pgstib>=500 & pgstib<600) | pgstib==340
gen civilservant = 0
replace civilservant = 1 if pgstib>=600 & pgstib<700
gen selfemployed = 0
replace selfemployed=1 if pgstib>410 & pgstib<440

gen All=0
replace All=1 if (bluecollar==1 | whitecollar==1 | civilservant==1 | selfemployed==1 )
gen notcivilserv=All
replace notcivilserv=0 if civilservant==1
gen dependent=All
replace dependent=0 if selfemployed==1
gen occupation=.
replace occupation=1 if bluecollar==1
replace occupation=2 if whitecollar==1
replace occupation=3 if civilservant==1
replace occupation=4 if selfemployed==1
label define occ_label 1 "bluecollar" 2 "whitecollar" 3 "civilservant"  4 "selfemployed", replace
label var occupation "Type of Occupation"
label val occupation occ_label 
tab occupation

/* Subgroups selfemployed */
gen freiberufler=0 /* Liberal professions e.g. selfemployed physicians, lawyers, etc */
replace freiberufler=1 if pgstib>420 & pgstib<424
gen entrepreneur=0
replace entrepreneur=1 if selfemployed==1 & freiberufler==0  
gen selfemp_noemployees=0 
replace selfemp_noemployees=1 if (pgstib==411 | pgstib==421 | pgstib==431)
gen selfemp_withemployees=0
replace selfemp_withemployees=1 if selfemployed==1 & selfemp_noemployees==0  

/* generate iscos */
replace e11105=. if e11105<0
	
tostring  e11105, gen(isco88)
gen isco88_single=substr(isco88,1,1)
gen isco88_two=substr(isco88,1,2)
destring isco88, replace
destring isco88_single, replace
destring isco88_two, replace
replace isco88_single=. if isco88_single==0
replace isco88_two=. if isco88_two==0
tab isco88_single, gen(isco_)
foreach  x of numlist 11 12 13 21 22 23 24 31 32 33 34 41 42 51 52 71 72 73 74 81 82 83 91 92 93 99 {
	 gen isco_`x'=0
	 replace isco_`x'=1 if isco88_two==`x'
}
label var isco_1 "Legislators, senior officials and managers"
label var isco_11 " Legislators and senior officials"
label var isco_12 "Corporate managers"
label var isco_13 "General managers"

label var isco_2 "Professionals"
label var isco_21 "Physical, mathematical and engineering science professionals"
label var isco_22 "Life science and health professional"
label var isco_23 "Teaching professionals"
label var isco_24 "Other Professionals"

label var isco_3 "Technicians and associate professionals"
label var isco_31 "Physical and engineering science associate professionals"
label var isco_32 "Life science and health associate professionals"
label var isco_33 "Teaching associate professionals"
label var isco_34 "Other associate professionals"

label var isco_4 "Clerks"
label var isco_41 "Office clerks"
label var isco_42 "Customer service clerks"

label var isco_5 "Service workers and shop and market sales workers"
label var isco_51 "Personal and protective services workers"
label var isco_52 "Models, salespersons and demonstrators"

label var isco_6 "Skilled agricultural and fishery workers"

label var isco_7 "Craft and related trade workers"
label var isco_71 "Extraction and building trade workers"
label var isco_72 "Metal, machinery and related trades workers"
label var isco_73 "Precision, handicraft, printing and related trades workers"
label var isco_74 "Other craft and related trades workers"

label var isco_8 "Plant and machine operators and assemblers"
label var isco_81 "Stationary plant and related operators"
label var isco_82 "Machine operators and assemblers"
label var isco_83 "Drivers and mobile plant operators"

label var isco_9 "Elementary occupations"
label var isco_91 "Sales and services elementary occupations"
label var isco_92 "Agricultural, fishery and related labourers"
label var isco_93 "Labourers in mining, construction, manufacturing and transport"
label var isco_99 "Others"

/* Generate additional variables */ 
replace sex = 0 if sex == 2
replace sex = . if sex <0
gen double east=.
replace east=1 if sampreg==2
replace east=0 if sampreg==1
gen age=year-gebjahr if gebjahr~=.
gen age2=age^2
gen kids=0
replace kids=1 if hlc0043>0
gen nchild=hlc0043
gen double   disab = plb0022 == 8

gen experience=pgexpft+0.5*pgexppt
foreach var of varlist pgexpft pgexppt pgexpue pgerwzt experience {
	gen `var'2=`var'*`var'
} 
replace ijob1=0 if ijob1<0
replace ijob2=0 if ijob2<0
replace iself=0 if iself<0

# del;
gen double bra_cats = 0;
replace bra_cats   = 1 if (pgnace == 29| pgnace == 15 | pgnace == 30| pgnace == 31| pgnace == 32|
				pgnace == 33| pgnace == 34| pgnace == 35 )& pgnace < .;
replace bra_cats   = 2 if (pgnace == 10 | pgnace == 11 |pgnace == 12|pgnace == 13| pgnace == 14|
				pgnace == 40| pgnace == 41)& pgnace < .;
replace bra_cats   = 3 if (pgnace == 20 | pgnace == 21 |pgnace == 22| pgnace == 23| pgnace == 24|
				pgnace == 25)& pgnace < .;
replace bra_cats   = 4 if (pgnace ==26 | pgnace == 45)& pgnace < .;
replace bra_cats   = 5 if (pgnace == 27| pgnace == 28)& pgnace < .;
replace bra_cats   = 6 if (pgnace == 17 | pgnace == 18| pgnace == 19)& pgnace < .;
replace bra_cats   = 7 if (pgnace == 50 | pgnace == 51| pgnace == 52)& pgnace < .;
replace bra_cats   = 8 if (pgnace == 60 | pgnace == 61 | pgnace == 62| pgnace == 63| pgnace == 64)& pgnace < .;
replace bra_cats   = 9 if (pgnace == 72 | pgnace == 73 | pgnace == 75 |
				pgnace == 80 | pgnace == 85 | pgnace == 90)& pgnace < .;
replace bra_cats  = 10 if (pgnace == 55| pgnace == 65 | pgnace == 66 | pgnace == 67 | pgnace == 70 |
				pgnace == 71 | pgnace == 74 | pgnace == 37)& pgnace < .;
replace bra_cats  = 11 if (pgnace == 36 | pgnace == 16| pgnace == 91 | pgnace == 92 | pgnace == 93 | 
				pgnace == 95 | pgnace == 96| pgnace == 97| pgnace == 98| pgnace == 99|
				pgnace == 100)& pgnace < .;
replace bra_cats  = 12 if (pgnace == 1|pgnace== 2 | pgnace == 5)& pgnace < .;
qui tab bra_cats, gen(bracatd);	
#d cr

/*Generate unemployment probability cells*/ 
/*Gen employment categories: pgstib = 12 unemployed, pgstib>=200 working*/
gen unemployed=0
replace unemployed = 1 if pgstib==12
sort pid year
gen unemployed_next_year = 0
replace unemployed_next_year = 1 if unemployed == 0 & f.unemployed == 1
gen workforce=0
replace workforce= 1 if (pgstib==12 | pgstib>=200)
/*Gen age categories*/
gen age_cat=1
replace age_cat=2 if age>30
replace age_cat=3 if age>40
replace age_cat=4 if age>50
replace age_cat=5 if age>60
/*gen education categories*/
gen double educ= inrange(pgisced,0,2) /*up to general elemantary school*/
replace  educ= 2 if inrange(pgisced,3,4) /*"middle vocational or vocational school*/
replace  educ= 3 if inrange(pgisced,5,6) /*"higher vocational or higher education*/
gen mediumeduc=0
replace mediumeduc=1 if educ==2
gen higheduc=0
replace higheduc=1 if educ==3
/* gen variable for number of young kids */
gen youngkid_help=0
gen midkid_help=0
gen oldkid_help=0
bys hid year: replace youngkid_help=1 if age<3
bys hid year: replace midkid_help=1 if age<6 & age>=3
bys hid year: replace oldkid_help=1 if age>=6 & age<18
bys hid year: egen youngkid=max(youngkid_help)
bys hid year: egen midkid=max(midkid_help)
bys hid year: egen oldkid=max(oldkid_help)
drop youngkid_help midkid_help oldkid_help
sum youngkid midkid oldkid
/* define marital status */
sort year hid stell
gen double partHVd = stell==11 | stell==13 | stell==12
egen double partHV = sum(partHVd), by(year hid)
gen double 	famstat0=1 if stell==11 
replace famstat0=2 if stell[_n+1]==12 | stell[_n+1]==13
replace famstat0=3 if partHV==0
egen double famstat = max(famstat0), by (hid year)
sum famstat

forval x=1/3{
	gen famstat`x'=0
	replace famstat`x'=1 if famstat==`x'
}
label var famstat1 "Married"
label var famstat2 "Living with a partner"
label var famstat3 "Single"

gen region=.
replace region=1 if bula>=1 & bula<=4 /* Nordwest: Bremen, Hamburg, Niedersachsen, Schleswig-Holstein*/
replace region=2 if bula==5 /*NRW*/
replace region=3 if (bula==6 | bula==7 |bula==10) /*RP, Hessen, Saar */   
replace region=4 if bula==8 /*Baden Würtemberg*/
replace region=5 if bula==9 /*Bayern*/
replace region=6 if bula>=11 /*Ost*/

/* --------------------------( generate variable: Consumer Price Index for Germany (2010=100) )-------------------------- */
/* Source: Statistisches Bundesamt (Nov 2015): "Verbraucherpreisindex für Deutschland - Lange Reihen ab 1948", Wiesbaden. */
/* https://www.destatis.de/DE/Publikationen/Thematisch/Preise/Verbraucherpreise/VerbraucherpreisindexLangeReihen.html  */
gen cpi = .
replace	cpi	=	81.6	if	year	==	1996
replace	cpi	=	83.2	if	year	==	1997
replace	cpi	=	84		if	year	==	1998
replace	cpi	=	84.5	if	year	==	1999
replace	cpi	=	85.7	if	year	==	2000
replace	cpi	=	87.4	if	year	==	2001
replace	cpi	=	88.6	if	year	==	2002
replace	cpi	=	89.6	if	year	==	2003
replace	cpi	=	91		if	year	==	2004
replace	cpi	=	92.5	if	year	==	2005
replace	cpi	=	93.9	if	year	==	2006
replace	cpi	=	96.1	if	year	==	2007
replace	cpi	=	98.6	if	year	==	2008
replace	cpi	=	98.9	if	year	==	2009
replace	cpi	=	100		if	year	==	2010
replace	cpi	=	102.1	if	year	==	2011
replace	cpi	=	104.1	if	year	==	2012
replace	cpi	=	105.7	if	year	==	2013
replace	cpi	=	106.6	if	year	==	2014

label variable cpi "Consumer Price Index for Germany (2010=100)"

 /* deflate */
local vars uninc whr_pgtatzt whr_pgvebzt whr_paid_hours whr_e11101 whr_plb0241 savings w011ha w011hb w011hc w011hd w011he
if ${NETWAGES}==1{
	local vars `vars' virtual_income_pgtatzt virtual_income_pgvebzt virtual_income_paid_hours  virtual_income_e11101  virtual_income_plb0241
	local vars `vars' net_wage_pgtatzt net_wage_pgvebzt net_wage_paid_hours net_wage_e11101 net_wage_plb0241 
}
foreach var of varlist `vars' {
	replace `var'=100*`var'/cpi
}
	
/* gen logs for income variables */
foreach var in pgtatzt pgvebzt paid_hours e11101 plb0241{ 
	gen lwhr_`var'=log(whr_`var'+0.001)
}
if ${NETWAGES}==1{
	foreach var in pgtatzt pgvebzt paid_hours e11101 plb0241{
		gen double lnet_wage_`var'=log(net_wage_`var'+0.001)
		gen lvirtual_income_`var'=log(virtual_income_`var'+0.001)
	}
}
gen luninc=log(uninc+0.001) 

/* Generate and label logs of hours, teh dependnet variables */
foreach var of varlist e11101 paid_hours pgtatzt pgvebzt plb0241 savings {
	gen l`var'=log(`var')
}
label var le11101 "Log of Annual Hours"
label var lpaid_hours "Log of Paid Hours"
label var lpgtatzt "Log of Actual Hours"
label var lplb0241 "Log of Desired Hours"
label var lsavings "Log of Savings"

/* Generate place holders for variables of interest */
gen wage=.
lab var wage "Wage" 
gen income=.
label var income "Income"
gen uncertainty=.
label var uncertainty "Wage Risk"
gen lab_inc=.
label var lab_inc "Labor Income"

/* Label variables for summary statistics */
foreach dephour of varlist e11101 pgtatzt paid_hours pgvebzt plb0241 {
	label var whr_`dephour' "Gross Hourly Wage "
}
if ${NETWAGES}==1 {
	foreach dephour of varlist e11101 pgtatzt paid_hours pgvebzt plb0241 {
		label var net_wage_`dephour' "Net Hourly Wage"						
		label var virtual_income_`dephour' "Virtual Income"
	}
}

label var e11101 "Annual Hours worked"
label var pgtatzt "Hours worked"
label var paid_hours "Paid Hours"
label var pgvebzt "Contracted Hours"
label var plb0241 "Desired Weekly Hours"

label var dovertime "Overtime Work"
label var dovertime_paid "Paid Overtime Work"
label var uninc "Gross Non-labor Income p.a."
label var pglabgro "Gross Labor Income p.m."
label var pglabnet "Net Labor Income p.m." 
					
label var famstat1 "Married"
label var famstat2 "Partnered"
label var famstat3 "Single"

label var dependent "Employees" 
label var selfemployed "Self-employed"
label var bluecollar "Blue Collar"
label var whitecollar "White Collar"
label var civilservant "Civil Servant"

label var pgbilzt "Years of Education"
label var pgerwzt "Tenure"
label var experience "Work Experience" 
label var pgexpft "Work Experience - Full-Time"
label var pgexpft "Work Experience - Part-Time"
label var pgexpue "Unemployment Experience"

label var east "East Germany"
label var kids "Children"
label var youngkid "Children<3"
label var midkid "Children<6"
label var oldkid "Children<18"
label var age "Age"
label var age2 "Age_sq"
label var year "Year"

save "${DATA_PATH}raw_data.dta", replace
