/**********************************************************************************************/
/* Replication files for                                                                      */
/* Jessen, Robin, Rostam-Afschar, Davud, and Schmitz, Sebastian                               */
/* "How Important is Precautionary Labor Supply?" (2016)                                      */
/* risk_measures.do                                                                           */
/**********************************************************************************************/

/* predict unemployment probability */ 
if ${REGIONAL}==1{
	hetprob unemployed_next_year c.experience c.experience2 c.pgbilzt c.experience#c.pgbilzt c.experience2#c.pgbilzt i.ror i.isco88_single i.isco88_single#c.experience i.isco88_single#c.experience2 c.pgerwzt youngkid midkid oldkid i.year c.pgexpue, het(c.pgbilzt c.pgexpue) vce(robust)
	di in red "Please set the global REGIONAL to 0 or include spatial planning regions data"
}
else{
	hetprob unemployed_next_year c.experience c.experience2 c.pgbilzt c.experience#c.pgbilzt c.experience2#c.pgbilzt i.isco88_single i.isco88_single#c.experience i.isco88_single#c.experience2 c.pgerwzt youngkid midkid oldkid i.year c.pgexpue, het(c.pgbilzt c.pgexpue) vce(robust)
}
predict expunemployed, pr
label var expunemployed "Unempl. Risk"

/* Detrend wages to generate the uncertainty measure */
if ${DETRENDWAGE}==1{	
	global DETREND_VARS "c.experience c.experience2 i.mediumeduc c.experience#i.mediumeduc c.experience2#i.mediumeduc higheduc c.experience#i.higheduc c.experience2#i.higheduc"
	foreach var in $DEPVARS { /* Obtain varlist */
		di "`var'"
		local  vars `vars' whr_`var' 
		if ${NETWAGES}==1{
			local vars `vars' net_wage_`var' 
		}
	}
	local vars `vars' other_inc_net
			
	qui sum year
	local highest_year=r(max)
	local firstyear=${FIRSTYEAR}+1
	
	foreach var of varlist `vars' {
		gen l`var'_backup=l`var'
		gen resid=.
		forvalues year=`firstyear'/`highest_year'{
			reg d.l`var' ${DETREND_VARS} if year==`year'
			predict aux if year==`year', resid 
			replace resid=aux if year==`year'
			drop aux
		}
		replace l`var'=resid
		drop resid 
	}
}	

if ${WAGERISK}==1{
	/* calculate wage risk meassures, using last 5 years */
		xtset pid year
		sort pid year
		foreach var of varlist `vars' {
			gen double sdl_`var'=. /* standard deviation of log */
			gen double varl_`var'=. /* variance of log */
			gen double sdlf_`var'=. /* standard deviation of log, forward-looking */
			gen double varlf_`var'=. /* variance of log, forward-looking */
			gen double varl5_`var'=.
			gen double sdl5_`var'=.

			forvalues period=2000/2011 {
				global period `period'
				gen self_emp`period'=0
				replace self_emp`period'=1 if year==`period' & selfemployed==1
				gen whitecollar`period'=0
				replace whitecollar`period'=1 if year==`period' & whitecollar==1
				gen bluecollar`period'=0
				replace bluecollar`period'=1 if year==`period' & bluecollar==1
				gen civilservant`period'=0
				replace civilservant`period'=1 if year==`period' & civilservant==1
				
				by pid : egen  self_emp`period'1=max(self_emp`period')
				by pid : egen  whitecollar`period'1=max(whitecollar`period')
				by pid : egen  bluecollar`period'1=max(bluecollar`period')
				by pid : egen  civilservant`period'1=max(civilservant`period')
			}
			
			forvalues period=2000/2011 {
				/*Backward looking*/
	 
				bys pid: egen mean_l`var'=mean(l`var') if year<`period'   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				by pid: egen obsl=count(l`var') if year<`period' & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				gen variationl=(l`var'-mean_l`var')^2 if year<`period'    & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				by pid: egen totvarl= total(variationl) if year<`period'   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar, missing 
				gen variancel=totvarl/(obsl-1) if year<`period'   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				replace varl_`var'=variancel[_n-1] if year==`period' & pid==pid[_n-1]
				replace sdl_`var'=variancel[_n-1]^0.5 if year==`period' & pid==pid[_n-1]
				
				drop variancel totvarl obsl  mean_l`var' variationl 

				/*Backward looking 5 year window*/
				global RISKHORIZON  "&year>`period'-6 " 
	 
				bys pid: egen mean_l`var'=mean(l`var') if year<`period' ${RISKHORIZON}  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				by pid: egen obsl=count(l`var') if year<`period' ${RISKHORIZON}  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				gen variationl=(l`var'-mean_l`var')^2 if year<`period' ${RISKHORIZON}    & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				by pid: egen totvarl= total(variationl) if year<`period' ${RISKHORIZON}   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar, missing 
				gen variancel=totvarl/(obsl-1) if year<`period' ${RISKHORIZON}  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				replace varl5_`var'=variancel[_n-1] if year==`period' & pid==pid[_n-1]
				replace sdl5_`var'=variancel[_n-1]^0.5 if year==`period' & pid==pid[_n-1]
				
				drop variancel totvarl obsl  mean_l`var' variationl 
			
			
				/*Forward looking*/
				bys pid: egen mean_lf`var'=mean(l`var') if year>`period'  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				by pid: egen obslf=count(l`var') if year>`period'   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				gen variationlf=(l`var'-mean_lf`var')^2 if year>`period'    & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				by pid: egen totvarlf= total(variationlf) if year>`period'   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar, missing 
				gen variancelf=totvarlf/(obslf-1) if year>`period'   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
				replace varlf_`var'=variancelf[_n+1] if year==`period' & pid==pid[_n+1]
				replace sdlf_`var'=variancelf[_n+1]^0.5 if year==`period' & pid==pid[_n+1]
						
				drop variancelf totvarlf obslf  mean_lf`var' variationlf 
			}
			
			forvalues period=2000/2011{	
				drop self_emp`period' self_emp`period'1   civilservant`period' civilservant`period'1 bluecollar`period'1 bluecollar`period'  whitecollar`period'1  whitecollar`period'
			}
		
		}
}

/* Back to normal wages after the generation of the uncertainty measure */
if ${DETRENDWAGE}==1{	
	foreach var of varlist `vars' {
			replace l`var'=l`var'_backup
			drop l`var'_backup
	}
}	

/* Alternative: Wage risk measure without detrending (wod) */
if ${WAGERISK}==1{
	xtset pid year
	sort pid year
	foreach var of varlist `vars' {
		gen double sdl_wod_`var'=. /* standard deviation of log */
		gen double  varl_wod_`var'=. /* variance of log */
		forvalues period=2000/2011{
			global period `period'
			gen self_emp`period'=0
			replace self_emp`period'=1 if year==`period' & selfemployed==1
			gen whitecollar`period'=0
			replace whitecollar`period'=1 if year==`period' & whitecollar==1
			gen bluecollar`period'=0
			replace bluecollar`period'=1 if year==`period' & bluecollar==1
			gen civilservant`period'=0
			replace civilservant`period'=1 if year==`period' & civilservant==1
			by pid : egen  self_emp`period'1=max(self_emp`period')
			by pid : egen  whitecollar`period'1=max(whitecollar`period')
			by pid : egen  bluecollar`period'1=max(bluecollar`period')
			by pid : egen  civilservant`period'1=max(civilservant`period')
		}
		
		forvalues period=2000/2011{	
			bys pid: egen mean_l`var'=mean(l`var') if year<`period' ${RISKHORIZON}  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
			by pid: egen obsl=count(l`var') if year<`period' ${RISKHORIZON}  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
			gen variationl=(l`var'-mean_l`var')^2 if year<`period' ${RISKHORIZON}    & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
			by pid: egen totvarl= total(variationl) if year<`period' ${RISKHORIZON}   & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar, missing 
			gen variancel=totvarl/(obsl-1) if year<`period' ${RISKHORIZON}  & self_emp`period'1==selfemployed & civilservant`period'1==civilservant &  bluecollar`period'1==bluecollar &  whitecollar`period'1==whitecollar
			replace varl_wod_`var'=variancel[_n-1] if year==`period'
			replace sdl_wod_`var'=variancel[_n-1]^0.5 if year==`period'

			drop variancel totvarl obsl  mean_l`var' variationl 
		}
		
		forvalues period=2000/2011{	
			drop self_emp`period' self_emp`period'1   civilservant`period' civilservant`period'1 bluecollar`period'1 bluecollar`period'  whitecollar`period'1  whitecollar`period'
		}
	}
}

/* Alternative risk measure, subjective worries abour personal economic situation */
gen noworries=0
gen someworries=0
gen bigworries=0
replace noworries=. if plh0033<0
replace someworries=. if plh0033<0
replace bigworries=. if plh0033<0
replace noworries=1 if plh0033==3
replace someworries=1 if plh0033==2
replace bigworries=1 if plh0033==1
label var noworries "No financial worries"
label var someworries "Some financial worries"
label var bigworries "Big financial worries"



/* Label variables for summary statistics */
foreach dephour of varlist $DEPVARS {
	label var sd${l}_whr_`dephour' "Gross Wage Risk" 

	if ${NETWAGES}==1 {
		label var sd${l}_net_wage_`dephour' "Net Wage Risk" 
	
	}
}
