/**********************************************************************************************/
/* Replication files for                                                                      */
/* Jessen, Robin, Rostam-Afschar, Davud, and Schmitz, Sebastian                               */
/* "How Important is Precautionary Labor Supply?" (2016)                                      */
/* sample_restriction.do                                                                      */
/**********************************************************************************************/

use "${DATA_PATH}raw_data", clear

/*Define sample*/
xtset pid year
sort pid year
gen pmarker = 0
replace pmarker = 1 if [pid~=pid[_n-1]]
count
scalar lastsample = r(N)
local rownames
local obs
local obs `=scalar(lastsample)',-1
local rownames `rownames' initial_sample

/* Drop people with incomplete interviews/information */
di "The initial full sample has " r(N) " persons."
drop if netto>30
count
di in red scalar(lastsample)-r(N) " persons eliminated because" in yellow " incomplete interviews, " r(N) " remaining"

capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	

local rownames `rownames' incomplete_interviews
count
scalar lastsample = r(N)

/* drop people without household id */
di "The full sample has " r(N) " persons."
gen dropdummy=1 if hid==.
bys pid: egen max_dropdummy=max(dropdummy)  
drop if max_dropdummy==1
drop max_dropdummy dropdummy
count
	di in red scalar(lastsample)-r(N) " persons eliminated because"  in yellow " of no household id, " r(N) " remaining"
capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' no_hh_id
scalar lastsample = r(N)

# del cr		
sort pid year
/* drop women */
di "The sample has " r(N) " persons."
drop if sex!=1
count
	di in red scalar(lastsample)-r(N) " persons eliminated because"  in yellow " of female gender, " r(N) " remaining"
capture confirm existence `obs'
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' dropwomen
scalar lastsample = r(N)

/* drop singles */
di "The sample has " r(N) " persons."
drop if famstat>1
count
	di scalar(lastsample)-r(N) " persons eliminated because"  in yellow " not in wedlock, " r(N) " remaining"
capture confirm existence `obs'

if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' drop_singles
scalar lastsample = r(N)

do "${DOFILES}risk_measures.do"

/* keep age 25-55 */
di "The restricted sample has " r(N) " persons."
keep if age>=25 & age<=55  
count
di in red  scalar(lastsample)-r(N) " persons eliminated because"  in yellow " of cross-sectional age (25-55), " r(N) " remaining"
capture confirm existence `obs'

if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' drop_csage
scalar lastsample = r(N)

/* drop people in training, in military, etc */
di "The sample has " r(N) " persons."
gen dropperson=0
/*13: pensionist; 15: Military, 11: trainee, 110: apprenitce, 120: apprentice trainee industry, 130: apprentice trainee trade, 140: trainee or intern, 150: aspirant,
isco_6: agricultural workers*/
replace dropperson=1 if pgstib==13 | pgstib==15 | pgstib==11 | pgstib==110 | pgstib==120 | pgstib==130 | pgstib==140 | pgstib==150  | isco_6==1
drop if dropperson==1
drop dropperson
count
di in red  scalar(lastsample)-r(N) " persons eliminated because"  in yellow " in eductaion, retirement, agriculture, or military " r(N) " remaining"

capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
local rownames `rownames' drop_pgstib
scalar lastsample = r(N)	

/* drop transfer recipients */
di "The sample has " r(N) " persons."
gen transfer=0
replace transfer=1 if hlc0048==1 /* Sozialhilfe */
replace transfer=1 if hlc0052==1 /* ALGII */
bys pid: egen max_transfer=max(transfer)
drop if max_transfer<. & max_transfer>0
drop max_transfer transfer
count
di scalar(lastsample)-r(N) " persons eliminated, " r(N) " remaining"
capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' drop_transfer
scalar lastsample = r(N)

/* drop people with low observed hours */
di "The sample has " r(N) " persons."
gen drophours=0 
replace drophours=1 if ${DEPVAR}==0
sum ${DEPVAR}, det
replace drophours=1 if ${DEPVAR}<20
drop if drophours==1
drop drophours
count
di in red scalar(lastsample)-r(N) " persons eliminated because"  in yellow " very low observed hours, " r(N) " remaining"
capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' drop_low_hours
scalar lastsample = r(N)	

/* drop people with unrealistic changes in hours */
di "The sample has " r(N) " persons."
gen d${DEPVAR}=${DEPVAR}/l.${DEPVAR} 

gen drophours=1 if (d${DEPVAR}>2.5 | d${DEPVAR}<0.4) & d${DEPVAR}!=.
by pid: egen max_drophours=max(drophours)
drop if max_drophours==1
drop drophours max_drophours d${DEPVAR}
count
di in red scalar(lastsample)-r(N) " persons eliminated because"  in yellow " dramatic changes in hours, " r(N) " remaining"
capture confirm existence `obs'

if _rc!=0{
	local obs `=scalar(lastsample)-scalarr(N)',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' "drop_unreal_${DEPVAR}_changes"
scalar lastsample = r(N)

/* drop people with unrealistic changes and levels in gross wages */
sort pid year
di "The sample has " r(N) " persons."
gen dwhr=lwhr_${DEPVAR}/l.lwhr_${DEPVAR}
gen dropwage=1 if (dwhr>2.5 | dwhr<0.4) & dwhr!=.
replace dropwage=1 if whr_${DEPVAR}>100 & whr_${DEPVAR}!=.
by pid: egen max_dropwage=max(dropwage)
drop if max_dropwage==1
drop max_dropwage dropwage
count
di in red  scalar(lastsample)-r(N) " persons eliminated because"  in yellow " dramatic gross wage growth or level, " r(N) " remaining"
capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' drop_unreal_wchanges
scalar lastsample = r(N)
sort pid year

/* drop people with missing occupation */
di "The sample has " r(N) " persons."
drop if All==0
count if pmarker == 1
di in red scalar(lastsample)-r(N) " persons eliminated because"  in yellow " missing occupation, " r(N) " remaining"

/* number of people with observed net wage and net wage risk */
if ${NETWAGES}==1{
replace lab_inc=pglabnet
replace wage=lnet_wage_${DEPVAR}
replace uncertainty=sd${l}_net_wage_${DEPVAR}
}
else{
replace lab_inc=pglabgro
replace wage=lwhr_${DEPVAR}
replace uncertainty=sd${l}_whr_${DEPVAR}
}
reg l${DEPVAR} uncertainty expunemployed  wage ${CONTROLS} [aw=phrf] if ${MAINOCC}==1 , vce(cluster pid)
gen olssample=e(sample)
count if olssample==1
capture confirm existence `obs'
di _rc
if _rc!=0{
	local obs `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}
else{
	local obs `obs' \ `=scalar(lastsample)-scalar(r(N))',`=scalar(r(N))'
}	
local rownames `rownames' keep_with_net_wage_and_risk
scalar lastsample = r(N)
sort pid year

/* export table with numbers of observations */
matrix define obs =(`obs')
matrix rownames obs= `rownames'
matrix colnames obs=eliminated remaining
outtable using "${TABLES}\observations_${DEPVAR}", mat(obs) f(%9.0f) replace 

/* normalise Risk-meassures and  for estimation */
foreach hour of varlist $DEPVARS  {
	foreach type in sd${l} sd${l}_wod  {
		gen `type'_whr_`hour'_BU=`type'_whr_`hour'
		sum `type'_whr_`hour' [aw=phrf] if olssample==1 
		replace `type'_whr_`hour'=`type'_whr_`hour'/r(sd)
		label var `type'_whr_`hour'_BU "Gross Wage Risk"
				
		if ${NETWAGES}==1 { 
			gen `type'_net_wage_`hour'_BU=`type'_net_wage_`hour'
			sum `type'_net_wage_`hour' [aw=phrf] if olssample==1 
			replace `type'_net_wage_`hour'=`type'_net_wage_`hour'/r(sd)
			label var `type'_net_wage_`hour'_BU "Net Wage Risk"
		}
	}
}	

gen expunemployed_BU=expunemployed
sum expunemployed [aw=phrf] if olssample==1 
replace expunemployed=expunemployed/r(sd)
label var expunemployed_BU "Unemployment Risk"

/*Risk measure only for continuously employed */
bys pid: egen max_year=max(year)
bys pid: egen min_year=min(year)
gen year_dif=max_year-min_year

if ${NETWAGES}==1 { 
bys pid: egen count_wage=count(net_wage_${DEPVAR})
gen sdlcont_net_wage_${DEPVAR}=sd${l}_net_wage_${DEPVAR} if count_wage==year_dif+1
}
else{
bys pid: egen count_wage=count(whr_${DEPVAR})
gen sdlcont_net_wage_${DEPVAR}=sd${l}_whr_${DEPVAR} if count_wage==year_dif+1
}
drop max_year min_year year_dif count_wage

sort pid year
save "${DATA_PATH}estimation.dta", replace
